@@ -341,7 +341,7 @@ void          gegl_node_set              (GeglNode      *node,
  * gegl_node_set_valist:
  * @node: a #GeglNode
  * @first_property_name: name of the first property to set
- * @...: value for the first property, followed optionally by more name/value
+ * @args: value for the first property, followed optionally by more name/value
  * pairs, followed by NULL.
  *
  * valist version of #gegl_node_set
@@ -373,7 +373,7 @@ void          gegl_node_get              (GeglNode      *node,
  * gegl_node_get_valist:
  * @node: a #GeglNode
  * @first_property_name: name of the first property to get.
- * @...: return location for the first property, followed optionally by more
+ * @args: return location for the first property, followed optionally by more
  * name/value pairs, followed by NULL.
  *
  * valist version of #gegl_node_get
@@ -658,6 +658,16 @@ GeglNode    * gegl_node_get_producer     (GeglNode      *node,
                                           gchar         *input_pad_name,
                                           gchar        **output_pad_name);
 
+/**
+ * gegl_node_has_pad:
+ * @node: the node we are querying
+ * @pad_name: the pad name we are looking for
+ *
+ * Returns TRUE if the node has a pad with the specified name
+ */
+gboolean      gegl_node_has_pad          (GeglNode      *node,
+                                          const gchar   *pad_name);
+
 
 /***
  * Binding conveniences:
@@ -845,5 +855,43 @@ void           gegl_processor_destroy       (GeglProcessor *processor);
 GeglConfig      * gegl_config (void);
 
 
+/**
+ * gegl_node:
+ * @op_type:  the type of operation to create
+ * @first_property_name: 
+ * @...:
+ *
+ * Construct a GEGL node, connecting it to needed input nodes. The
+ * returned node does not have a parent but a single reference it
+ * is meant to be passed to gegl_graph () for gegl_graph () to assume
+ * its ownership. This is syntactic sugar for use from C, similar
+ * conveniences can easily be built externally in other languages.
+ *
+ * gegl_node(op_type, [key, value, [...]], NULL, [input, [aux]])
+ *
+ * Returns a new Gegl node.
+ */
+GeglNode *gegl_node (const gchar *op_type,
+                     const gchar *first_property_name,
+                     ...);
+
+
+/**
+ * gegl_graph:
+ * @node: the end result of a composition created with gegl_node()
+ *
+ * Creates a GeglNode containing a free floating graph constructed
+ * using gegl_node(). The GeglGraph adopts all the passed in nodes
+ * making it sufficient to unref the resulting graph.
+ *
+ * gegl_graph (gegl_node ("gegl:over", NULL,
+ *                        gegl_node (..), gegl_node (..)));
+ *
+ * Returns a GeglNode graph.
+ */
+GeglNode *gegl_graph (GeglNode *node);
+
+#define GEGL_ALIGNED __restrict__ __attribute__((__aligned__ (16)))
+
 G_END_DECLS
 #endif  /* __GEGL_H__ */
